@@ -1,5 +1,7 @@
 #!/bin/sh
-[ -f /usr/share/acpi-support/key-constants ] || exit 0
+
+test -f /usr/share/acpi-support/key-constants || exit 0
+
 manufacturer=`dmidecode --string system-manufacturer`
 case "$manufacturer" in
     LENOVO*)
