@@ -1,5 +1,6 @@
 #!/bin/sh
-[ -f /usr/share/acpi-support/key-constants ] || exit 0
+
+test -f /usr/share/acpi-support/key-constants || exit 0
 
 . /usr/share/acpi-support/key-constants
 acpi_fakekey $KEY_BRIGHTNESSDOWN
